import { FC, useEffect, useState } from "react";
import { useConnection, useWallet } from "@solana/wallet-adapter-react";
import {ASSOCIATED_TOKEN_PROGRAM_ID, Token, TOKEN_PROGRAM_ID} from "@solana/spl-token";
import {
  SOLCIAL_SWAP,
  displayPrice,
  SOLCIAL_MINT,
  parseSwap,
} from "@solcial.io/solana-client";
import { PublicKey, TransactionResponse } from "@solana/web3.js";
import b58 from "b58";


export const TradesView: FC = ({}) => {
  const { connection } = useConnection();
  const wallet = useWallet();
  const [swapsTx, setSwapTx] = useState([]);
  const [trades, setTrades] = useState([]);
  const [lastfetched, setLasfeteched] = useState(null);
  const [progress, setProgress] = useState(null);

  useEffect(() => {
      connection.getSignaturesForAddress(SOLCIAL_SWAP, {
        until: (lastfetched && (lastfetched.signature as string)) || undefined,
      }).then(tx=> setSwapTx(tx));
  }, []);

  useEffect(()=>{
    async function load() {
      const res = [];
      if(swapsTx != null && swapsTx.length > 0) {
        for (let i = 0; i < swapsTx.length; i++) {
          const p = Math.floor((100 * i + swapsTx.length) / swapsTx.length);
          setProgress(p);
          const chunkSize = 100; // empiricaly determined max size
          const txs = swapsTx.slice(i,i+chunkSize).map(s=>s.signature);
          const transactions = await connection.getTransactions(txs);
          const trades = (await Promise.all(transactions.map(async (t,j)=> {
            const tx = swapsTx[i+j];
            const parsed = await parseSwap(t);
            return parsed.map(data=>({tx, data}));
          }))).flatMap(t=>t);

          if(trades.length > 0) {
            res.push(...trades);
            setTrades([...res]);
          }

          i += chunkSize;
          //await delay(100);
        }
        setProgress(100);
    }
  }
    load();
    
  },[swapsTx]);

  const minBlockTime = swapsTx.length > 0 &&  new Date(Math.min(...swapsTx.map(t=>t.blockTime))* 1000);
  return (
    <div className="md:hero mx-auto p-4">
      <div className="md:hero-content flex flex-col">
        <h1 className="text-center text-5xl font-bold text-transparent bg-clip-text bg-gradient-to-tr from-[#9945FF] to-[#14F195]">
          Users
        </h1>
        <div className="stats bg-primary text-primary-content mx-3">

        <div className="stat">
          <div className="stat-title">Number of tx</div>
          <div className="stat-value">
          {swapsTx.length}
          </div>
          {swapsTx.length == 0 && <div className="stat-desc">loading ...</div>}
          {minBlockTime && <div className="stat-desc">From : {minBlockTime.toLocaleString()}</div>}
        </div>

        <div className="stat">
          <div className="stat-title">Number of trades </div>
          <div className="stat-value">{trades.length}</div>
          <div className="stat-desc">{progress}%</div>
        </div>

      </div>
        <div className="text-center">
          <div className="overflow-x-auto">
            <table className="table table-compact w-full">
              <thead>
                <tr>
                  <th></th>
                  <th>blocktime</th>
                  <th>tx</th>
                  <th>swap</th>
                  <th>in</th>
                  <th>out</th>
                  <th>kind</th>
                  <th>price</th>
                </tr>
              </thead>
              <tbody>
                {trades.map((e,i) => (
                  <tr key={`${e.tx.signature}-${i}`}>
                    <th>{i}</th>
                    <th>
                      <div>{new Date(e.tx.blockTime*1000).toISOString()}</div>
                    </th>
                    <th>
                      <div>{e.tx.signature.toString().slice(0,5)}...</div>
                    </th>
                    <th>{e.data.swap.toBase58().slice(0,5)}...</th>
                    <th>{displayPrice(e.data.amountIn)}</th>
                    <th>{displayPrice(e.data.amountOut)}</th>
                    <th>{e.data.sell ? "SELL" : e.data.buy ? "BUY" : "UKN"}</th>
                    <th>{displayPrice(BigInt(e.data.price))}</th>
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
        </div>
      </div>
    </div>
  );
};
