import { FC, useEffect, useState } from "react";
import { SignMessage } from "../../components/SignMessage";
import { SendTransaction } from "../../components/SendTransaction";
import { useConnection, useWallet } from "@solana/wallet-adapter-react";
import {
  SOLCIAL_SWAP,
  getUserMint,
  getUserSwapAccount,
  getUsers,
  SOLCIAL_FEE,
  displayPrice,
} from "@solcial.io/solana-client";
import { ExplorerLink } from "components/ExplorerLink";
import { PublicKey } from "@solana/web3.js";
import Link from "next/link";

export const UsersPoolView: FC = ({}) => {
  const { connection } = useConnection();
  const wallet = useWallet();
  const [swapList, setSwapList] = useState([]);
  const [feesAmount, setFeeAmount] = useState(null);

  useEffect(() => {
      connection.getBalance(SOLCIAL_FEE).then(amount=>setFeeAmount(amount));
      getUsers(connection,SOLCIAL_SWAP,true).then(users=> setSwapList(users)).catch(err=>console.error(err));
  }, []);

  return (
    <div className="md:hero mx-auto p-4">
      <div className="md:hero-content flex flex-col">
        <h1 className="text-center text-5xl font-bold text-transparent bg-clip-text bg-gradient-to-tr from-[#9945FF] to-[#14F195]">
          Users
        </h1>
        <div className="stats bg-primary text-primary-content mx-3">

        <div className="stat">
          <div className="stat-title">Number of pools</div>
          <div className="stat-value">
          {swapList.length}
          </div>
          {swapList.length == 0 && <div className="stat-desc">loading ...</div>}
        </div>

        <div className="stat">
          <div className="stat-title">Number of swaps </div>
          <div className="stat-value"></div>
          <div className="stat-desc">Loading ...</div>
        </div>

        <div className="stat">
          <div className="stat-title">Fees </div>
          <div className="stat-value">{displayPrice(feesAmount,5)} SOL</div>
          {feesAmount == null && <div className="stat-desc">Loading ...</div>}
        </div>

      </div>
        <div className="text-center">
          <div className="overflow-x-auto">
            <table className="table table-compact w-full">
              <thead>
                <tr>
                  <th></th>
                  <th>avatar</th>
                  <th>wallet</th>
                  <th>User</th>
                  <th>ticker</th>
                  <th>mint</th>
                  <th>swap</th>
                  <th>mint A</th>
                  <th>mint B</th>
                </tr>
              </thead>
              <tbody>
                {swapList.map((e,i) => (
                  <tr>
                    <th>{i}</th>
                    <th><img /></th>
                    <th>{e.metadata.name}</th>
                    <th>
                      <ExplorerLink account={e.user} />
                    </th>
                    <th>
                      <ExplorerLink account={e.mintId} />
                    </th>
                    <th>{e.metadata.symbol}</th>
                    <th>
                      <Link href={`/swap/${e.swapId.toBase58()}`}>
                        <a className="flex flex-row link link-accent">
                          {e.swapId.toBase58().slice(0, 8)}...
                          {e.swapId
                            .toBase58()
                            .slice(e.swapId.toBase58().length - 8)}
                        </a>
                      </Link>
                    </th>
                    <th>
                      {new PublicKey(e.swap.mintA).toBase58().slice(0, 5)}...
                    </th>
                    <th>
                      {new PublicKey(e.swap.mintB).toBase58().slice(0, 5)}...
                    </th>
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
        </div>
      </div>
    </div>
  );
};
